alsa

package
v0.0.0-...-91206c6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 25, 2025 License: GPL-3.0 Imports: 1 Imported by: 2

Documentation

Overview

ALSA output driver.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Alsa

type Alsa struct {
	// contains filtered or unexported fields
}

Alsa aoutput driter handler structure.

func New

func New() *Alsa

New returns newly initialized alsa output driver.

func (*Alsa) AvailUpdate

func (a *Alsa) AvailUpdate() (size int, err error)

func (*Alsa) Close

func (a *Alsa) Close() error

func (*Alsa) Flush

func (a *Alsa) Flush() error

func (*Alsa) Open

func (a *Alsa) Open() error

func (*Alsa) Pause

func (a *Alsa) Pause() error

func (*Alsa) Paused

func (a *Alsa) Paused() bool

func (*Alsa) SetChannels

func (a *Alsa) SetChannels(channels int) error

func (*Alsa) SetSampleRate

func (a *Alsa) SetSampleRate(rate int) error

func (*Alsa) SetVolume

func (a *Alsa) SetVolume(vol int) error

func (*Alsa) Volume

func (a *Alsa) Volume() (int, error)

func (*Alsa) Wait

func (a *Alsa) Wait(maxDelay int) (ok bool, err error)

func (*Alsa) Write

func (a *Alsa) Write(buf []byte) (written int, err error)

Directories

Path Synopsis
asoundlib package is the simple wrapper for C alsa binding library.
asoundlib package is the simple wrapper for C alsa binding library.

Jump to