package
Version:
v0.0.0-...-91206c6
Opens a new window with list of versions in this module.
Published: Jun 25, 2025
License: GPL-3.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 2
Opens a new window with list of known importers.
Documentation
¶
type Msg struct {
Data interface{}
Result chan interface{}
}
func (n *Notify) Send(msg interface{}) <-chan interface{}
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.